@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-11-29 20:24:12
+@LastEditTime: 2021-12-21 19:50:16
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -69,7 +69,8 @@ class SyncPayOrderHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        is_log = bool(self.get_param("is_log", False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
