@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-12-20 15:59:20
+@LastEditTime: 2021-12-22 16:38:43
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -226,7 +226,7 @@ class ActInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
-        act_info_dict = act_base_model.get_act_info_dict(act_id,False)
+        act_info_dict = act_base_model.get_act_info_dict(act_id, False, False)
         if act_info_dict:
             if act_info_dict["app_id"] != app_id:
                 act_info_dict = {}
