@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2021-11-29 16:39:02
+@LastEditTime: 2021-12-20 18:31:22
 @LastEditors: HuangJianYi
 @Description: ip模块
 """
@@ -39,9 +39,15 @@ class SaveIpInfoHandler(ClientBaseHandler):
         show_pic = self.get_param("show_pic")
         sort_index = int(self.get_param("sort_index", 0))
         is_release = int(self.get_param("is_release", 1))
+        ip_type = int(self.get_param("ip_type", 0))
+        ip_summary = self.get_param("ip_summary")
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.save_ip_info(app_id, act_id, ip_id, ip_name, ip_pic, show_pic, sort_index, is_release)
+        invoke_result_data = ip_base_model.save_ip_info(app_id, act_id, ip_id, ip_name, ip_pic, show_pic, sort_index, is_release, ip_type, ip_summary)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -49,7 +55,10 @@ class SaveIpInfoHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data["new"].id)
 
 
@@ -94,13 +103,18 @@ class DeleteIpInfoHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         ip_id = int(self.get_param("ip_id", 0))
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.delete_ip_info(app_id, act_id, ip_id)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
         self.create_operation_log(OperationType.delete.value, "ip_info_tb", "DeleteIpInfoHandler", None, ip_id)
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -124,9 +138,15 @@ class ReleaseIpInfoHandler(ClientBaseHandler):
         ip_id = int(self.get_param("ip_id", 0))
         is_release = int(self.get_param("is_release", 0))
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.release_ip_info(app_id, act_id, ip_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
