@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-12-23 16:34:49
+@LastEditTime: 2021-12-24 09:52:13
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -27,6 +27,8 @@ class PayOrderListHandler(ClientBaseHandler):
         :param nick_name：用户昵称
         :param pay_date_start：订单支付时间开始
         :param pay_date_end：订单支付时间结束
+        :param main_pay_order_no：淘宝主订单号
+        :param sub_pay_order_no：淘宝子订单号
         :param page_size：页大小
         :param page_index：页索引
         :return:
@@ -36,24 +38,38 @@ class PayOrderListHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
-        nick_name = self.get_param("nick_name")
+        user_nick = self.get_param("nick_name")
         pay_date_start = self.get_param("pay_date_start")
         pay_date_end = self.get_param("pay_date_end")
+        main_pay_order_no = self.get_param("main_pay_order_no")
+        sub_pay_order_no = self.get_param("sub_pay_order_no")
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
         condition = ""
         params = []
-        order_by = "pay_date desc"
+        order_by = "create_date desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
         else:
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "pay_date desc"
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+
+        if main_pay_order_no:
+            condition += " and " if condition else ""
+            condition += "main_pay_order_no=%s"
+            params.append(main_pay_order_no)
+        if sub_pay_order_no:
+            condition += " and " if condition else ""
+            condition += "sub_pay_order_no=%s"
+            params.append(sub_pay_order_no)
+
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size=page_size, page_index=page_index, order_by=order_by, condition=condition, params=params)
+        page_info = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, page_size=page_size, page_index=page_index, field=field, order_by=order_by, condition=condition, params=params)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
@@ -89,7 +105,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
-        nick_name = self.get_param("nick_name")
+        user_nick = self.get_param("nick_name")
         order_no = self.get_param("order_no")
         real_name = self.get_param("real_name")
         telephone = self.get_param("telephone")
@@ -120,7 +136,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
@@ -139,7 +155,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         :param module_id：活动模块标识
         :param tb_user_id：用户标识
         :param user_open_id：open_id
-        :param user_nick：用户昵称
+        :param nick_name：用户昵称
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
         :param prize_type：奖品类型(1现货2优惠券3红包4参与奖5预售)
@@ -314,17 +330,16 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
-        nick_name = self.get_param("nick_name")
+        user_nick = self.get_param("nick_name")
         order_no = self.get_param("order_no")
         real_name = self.get_param("real_name")
         telephone = self.get_param("telephone")
         address = self.get_param("address")
-        real_name = self.get_param("real_name")
         order_status = int(self.get_param("order_status", -10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        page_size = int(self.get_param("page_size", 500))
 
         condition = ""
         params = []
@@ -340,7 +355,19 @@ class PrizeOrderExportHandler(ClientBaseHandler):
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
-        prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
+        prize_order_list_dict = []
+        if page_size <= 500:
+            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
+        else:
+            max_page_size = 100
+            repeat_count = page_size // max_page_size  # 循环次数
+            begin_page_index = page_index * repeat_count  # 开始页码
+            for i in range(repeat_count):
+                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
+                if len(list_dict) <= 0:
+                    break
+                prize_order_list_dict.extend(list_dict)
+
         ref_params = {}
         result_data = self.business_process_executed(prize_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
@@ -400,7 +427,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         :param module_id：活动模块标识
         :param user_id：用户标识
         :param open_id：open_id
-        :param user_nick：用户昵称
+        :param nick_name：用户昵称
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
         :param prize_type：奖品类型(1现货2优惠券3红包4参与奖5预售)
@@ -415,8 +442,6 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id =self.get_app_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 500))
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         order_no = self.get_param("order_no")
@@ -430,6 +455,8 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         pay_status = int(self.get_param("pay_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
 
         condition = ""
         params = []
@@ -445,7 +472,18 @@ class PrizeRosterExportHandler(ClientBaseHandler):
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
-        prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
+        prize_roster_list_dict = []
+        if page_size <= 500:
+            prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
+        else:
+            max_page_size = 100
+            repeat_count = page_size // max_page_size  # 循环次数
+            begin_page_index = page_index * repeat_count  # 开始页码
+            for i in range(repeat_count):
+                list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, max_page_size, begin_page_index + i, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
+                if len(list_dict) <= 0:
+                    break
+                prize_roster_list_dict.extend(list_dict)
         ref_params = {}
         result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
@@ -477,4 +515,102 @@ class PrizeRosterExportHandler(ClientBaseHandler):
             else:
                 data_row["状态"] = "已下单"
             result_list.append(data_row)
-        return result_list
\ No newline at end of file
+        return result_list
+
+
+class TaoPayOrderExportHandler(ClientBaseHandler):
+    """
+    :description: 淘宝支付订单批量导出
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 淘宝支付订单批量导出
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param user_open_id：open_id
+        :param nick_name：用户昵称
+        :param pay_date_start：订单支付时间开始
+        :param pay_date_end：订单支付时间结束
+        :param main_pay_order_no：淘宝主订单号
+        :param sub_pay_order_no：淘宝子订单号
+        :param page_size：页大小
+        :param page_index：页索引
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        user_open_id = self.get_param("user_open_id")
+        user_nick = self.get_param("nick_name")
+        pay_date_start = self.get_param("pay_date_start")
+        pay_date_end = self.get_param("pay_date_end")
+        main_pay_order_no = self.get_param("main_pay_order_no")
+        sub_pay_order_no = self.get_param("sub_pay_order_no")
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
+
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success("")
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+
+        if main_pay_order_no:
+            condition += " and " if condition else ""
+            condition += "main_pay_order_no=%s"
+            params.append(main_pay_order_no)
+        if sub_pay_order_no:
+            condition += " and " if condition else ""
+            condition += "sub_pay_order_no=%s"
+            params.append(sub_pay_order_no)
+
+        order_base_model = OrderBaseModel(context=self)
+        tao_pay_order_list_dict = []
+        if page_size <= 500:
+            tao_pay_order_list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, page_size, page_index, field=field, order_by=order_by, condition=condition, params=params).data
+        else:
+            max_page_size = 100
+            repeat_count = page_size // max_page_size  # 循环次数
+            begin_page_index = page_index * repeat_count  # 开始页码
+            for i in range(repeat_count):
+                list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, max_page_size, begin_page_index + i, field=field, order_by=order_by, condition=condition, params=params).data
+                if len(list_dict) <= 0:
+                    break
+                tao_pay_order_list_dict.extend(list_dict)
+
+        ref_params = {}
+        result_data = self.business_process_executed(tao_pay_order_list_dict, ref_params)
+        resource_path = OSS2Helper.export_excel(result_data)
+        return self.response_json_success(resource_path)
+
+    def business_process_executed(self, result_data, ref_params):
+        """
+        :description: 执行后事件
+        :param result_data:result_data
+        :param ref_params: 关联参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        result_list = []
+        for tao_pay_order_dict in result_data:
+            data_row = {}
+            data_row["淘宝主订单号"] = tao_pay_order_dict["main_pay_order_no"]
+            data_row["淘宝子订单号"] = tao_pay_order_dict["sub_pay_order_no"]
+            data_row["淘宝名"] = tao_pay_order_dict["user_nick"]
+            data_row["商家编码"] = tao_pay_order_dict["goods_code"]
+            data_row["商品名称"] = tao_pay_order_dict["goods_name"]
+            data_row["购买数量"] = tao_pay_order_dict["buy_num"]
+            data_row["支付金额"] = tao_pay_order_dict["pay_price"]
+            data_row["支付时间"] = TimeHelper.datetime_to_format_time(tao_pay_order_dict["pay_date"])
+            result_list.append(data_row)
+        return result_list
