@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-11-18 14:30:13
+@LastEditTime: 2021-12-22 18:19:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -133,7 +133,7 @@ class FrameBaseModel():
         :param check_user_nick:是否校验昵称为空
         :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒 
         :param acquire_lock_name:分布式锁名称，为空则不开启分布式锁校验功能
-        :param request_limit_num:请求限制数；0不限制
+        :param request_limit_num:请求限制数(指的是当前接口在指定时间内可以请求的次数，用于流量削峰，减少短时间内的大量请求)；0不限制
         :param request_limit_time:请求限制时间；默认1秒
         :return:
         :last_editors: HuangJianYi
