@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-12-17 10:32:26
+@LastEditTime: 2021-12-17 10:52:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -34,7 +34,7 @@ class IpBaseModel():
         except Exception as ex:
             pass
 
-    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release):
+    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary):
         """
         :description: 保存ip信息
         :param app_id：应用标识
@@ -45,6 +45,8 @@ class IpBaseModel():
         :param show_pic：展示图片
         :param sort_index：排序
         :param is_release：是否发布
+        :param ip_type：ip类型
+        :param ip_summary：ip描述
         :return
         :last_editors: HuangJianYi
         """
@@ -58,7 +60,7 @@ class IpBaseModel():
         ip_info = None
         old_ip_info = None
         is_add = False
-        ip_info_model = IpInfoModel(context=self)
+        ip_info_model = IpInfoModel(context=self.context)
         if ip_id > 0:
             ip_info = ip_info_model.get_entity_by_id(ip_id)
             if not ip_info or ip_info.app_id != app_id:
@@ -73,8 +75,10 @@ class IpBaseModel():
         ip_info.app_id = app_id
         ip_info.act_id = act_id
         ip_info.ip_name = ip_name
+        ip_info.ip_type = ip_type
         ip_info.ip_pic = ip_pic
         ip_info.show_pic = show_pic
+        ip_info.ip_summary = ip_summary
         ip_info.sort_index = sort_index
         ip_info.is_release = is_release
         ip_info.modify_date = SevenHelper.get_now_datetime()
@@ -106,9 +110,9 @@ class IpBaseModel():
         condition = "app_id=%s and act_id=%s"
         params = [app_id,act_id]
         if is_cache == True:
-            page_list, total = IpInfoModel(context=self).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"ip_info_list:actid_{act_id}",cache_expire=600)
+            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"ip_info_list:actid_{act_id}",cache_expire=600)
         else:
-            page_list, total = IpInfoModel(context=self).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
+            page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
