@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-12-15 13:44:00
+@LastEditTime: 2021-12-27 13:49:34
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -105,11 +105,13 @@ def seven_cloudapp_frame_route():
         (r"/server/delete_act_prize", prize_s.DeleteActPrizeHandler),  #删除活动奖品（假删除）
         (r"/server/review_act_prize", prize_s.ReviewActPrizeHandler),  #还原活动奖品
         (r"/server/release_act_prize", prize_s.ReleaseActPrizeHandler),  #上下架活动奖品
+        (r"/server/act_prize_export", prize_s.ActPrizeExportHandler),  #导出活动奖品列表
         (r"/server/pay_order_list", order_s.PayOrderListHandler),  #淘宝支付订单列表
         (r"/server/prize_order_list", order_s.PrizeOrderListHandler),  #奖品订单列表
         (r"/server/prize_roster_list", order_s.PrizeRosterListHandler),  #用户中奖记录列表
         (r"/server/prize_order_export", order_s.PrizeOrderExportHandler),  #导出奖品订单列表
         (r"/server/prize_roster_export", order_s.PrizeRosterExportHandler),  #导出用户中奖记录列表
+        (r"/server/tao_pay_order_export", order_s.TaoPayOrderExportHandler),  #导出淘宝订单列表
         (r"/server/update_prize_order_status", order_s.UpdatePrizeOrderStatusHandler),  #更新奖品订单状态
         (r"/server/update_prize_order_seller_remark", order_s.UpdatePrizeOrderSellerRemarkHandler),  #更新奖品订单卖家备注
         (r"/server/import_prize_order", order_s.ImportPrizeOrderHandler),  #导入发货订单
